==> drd-8.x-3.9.tar.gz: drd/modules/drd_pi_pantheon/src/Form/Settings.php <==
<?php

namespace Drupal\drd_pi_pantheon\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Class Settings.
 */
class Settings extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'drd_pi_pantheon.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'drd_pi_pantheon_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('drd_pi_pantheon.settings');

    $form['terminus'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Terminus'),
      '#default_value' => $config->get('terminus'),
      '#required' => TRUE,
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * @inheritDoc
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    parent::validateForm($form, $form_state);

    $terminus = $form_state->getValue('terminus');
    if (!file_exists($terminus)) {
      $form_state->setErrorByName('terminus', $this->t('File does not exist.'));
    }
    elseif (!is_executable($terminus)) {
      $form_state->setErrorByName('terminus', $this->t('File is not executable.'));
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);

    $this->config('drd_pi_pantheon.settings')
      ->set('terminus', $form_state->getValue('terminus'))
      ->save();
  }

}

==> drd-8.x-3.10.tar.gz: drd/modules/drd_pi_pantheon/src/Form/Settings.php <==
<?php

namespace Drupal\drd_pi_pantheon\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\drd_pi_pantheon\Entity\Account;

/**
 * Class Settings.
 */
class Settings extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      Account::getConfigName(),
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'drd_pi_pantheon_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config(Account::getConfigName());

    $form['terminus'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Terminus'),
      '#default_value' => $config->get('terminus'),
      '#required' => TRUE,
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * @inheritDoc
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    parent::validateForm($form, $form_state);

    $terminus = $form_state->getValue('terminus');
    if (!file_exists($terminus)) {
      $form_state->setErrorByName('terminus', $this->t('File does not exist.'));
    }
    elseif (!is_executable($terminus)) {
      $form_state->setErrorByName('terminus', $this->t('File is not executable.'));
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    parent::submitForm($form, $form_state);

    $this->config(Account::getConfigName())
      ->set('terminus', $form_state->getValue('terminus'))
      ->save();
  }

}
